@@ -5,8 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Package-Version: 1.8
-;; Package-Revision: ebde926c159c
+;; Package-Version: 1.9
+;; Package-Revision: 7641bf620bf2
 ;; Package-Requires: ((emacs "29.1") (compat "30"))
 ;; URL: https://github.com/minad/osm
 ;; Keywords: network, multimedia, hypermedia, mouse
@@ -1673,8 +1673,8 @@ See `osm-search-server' and `osm-search-language' for customization."
              (osm--table-with-metadata
               results '((display-sort-function . identity)
                         (cycle-sort-function . identity)
-                        (eager-display . t))
-              nil t nil t))
+                        (eager-display . t)))
+             nil t nil t)
             results)
            (error "No selection"))))
     (osm--goto (cadr selected) (caddr selected)
